fancy_dio_inspector_personal library

Classes

FancyDioInspectorConsoleOptions
FancyDioInspectorL10nOptions
FancyDioInspectorOptions
This is used to configure the FancyDioInspector package.
FancyDioInspectorTileOptions
It is used to configure the FancyDioInspectorView widget.
FancyDioInspectorView
A view that displays the network requests, responses and errors.
FancyDioInterceptor
FancyElevatedButton
HttpScopeView
A view that displays the network requests, responses and errors.

Typedefs

OnErrorCreated = void Function(DioException err)
OnRequestCreated = void Function(RequestOptions options)
OnResponseCreated = void Function(Response response)