appBarText property
appBarText is used to change the text of the app bar. Defaults to
Network Logs.
Implementation
final String appBarText;
appBarText is used to change the text of the app bar. Defaults to
Network Logs.
final String appBarText;