responsesText property
responsesText is used to change the text of the responses tab. Defaults
to Responses.
Implementation
final String responsesText;
responsesText is used to change the text of the responses tab. Defaults
to Responses.
final String responsesText;