searchHintText property
searchHintText is used to change the hint text of the search field.
Defaults to Search.
Implementation
final String searchHintText;
searchHintText is used to change the hint text of the search field.
Defaults to Search.
final String searchHintText;