HttpScopeView class

A view that displays the network requests, responses and errors.

Inheritance

Constructors

HttpScopeView({FancyDioInspectorTileOptions tileOptions = const FancyDioInspectorTileOptions(), FancyDioInspectorL10nOptions l10nOptions = const FancyDioInspectorL10nOptions(), Widget? leading, List<Widget>? actions, ThemeData? themeData, Key? key, FancyItemCustomButtonBuilder? customButtonBuilder})
const

Properties

actions List<Widget>?
actions are used to place widgets after the title.
final
customButtonBuilder → FancyItemCustomButtonBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
l10nOptions FancyDioInspectorL10nOptions
The options for the UI localization. If any of the value is null, the default value will be used.
final
leading Widget?
leading is used to place a widget before the title.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeData ThemeData?
The theme data for the view. If this is null, FancyThemeData will be used.
final
tileOptions FancyDioInspectorTileOptions
The options for the dio tiles. If this is null, the default options will be used.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited