l10nOptions property
The options for the UI localization.
If any of the value is null, the default value will be used.
Implementation
final FancyDioInspectorL10nOptions l10nOptions;
The options for the UI localization.
If any of the value is null, the default value will be used.
final FancyDioInspectorL10nOptions l10nOptions;